package com.example;

import java.util.logging.*;

import org.infinispan.client.hotrod.*;
import org.infinispan.client.hotrod.configuration.*;

public class HotRodClient {
    private static Logger LOG = Logger.getLogger(HotRodClient.class.getName());

    private RemoteCacheManager cacheManager;
    private RemoteCache<String, Object> cache;

    public HotRodClient(String serverList, String cacheName) {
        connect(serverList);
        selectCache(cacheName);
    }

    private void connect(String serverList) {
        LOG.info("connect called: + serverList");
        ConfigurationBuilder builder = new ConfigurationBuilder();
        builder.addServers(serverList);
        cacheManager = new RemoteCacheManager(builder.build());
        LOG.info("Connected.");
    }

    public void disconnect() {
        LOG.info("disconnect called.");
        if (cacheManager != null) {
            cacheManager.stop();
            cacheManager = null;
            cache = null;
            LOG.info("Disconnected");
        }
    }

    private void selectCache(String cacheName) {
        if (cacheName != null) {
            cache = cacheManager.getCache(cacheName);
        } else {
            cache = cacheManager.getCache();
        }
        LOG.info("Selected cache: " + cache.getName());
    }

    public Object get(String key) {
        Object val = cache.get(key);
        return val;
    }

    public void put(String key, Object value) {
        cache.put(key, value);
    }
}
